unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, SQLDB, Forms, Controls, Graphics, Dialogs, ExtCtrls, StdCtrls, SQLite3Conn,
  LCLIntf, LR_CodeReport, LR_Class, LR_DBSet, Printers, LR_DSet, lrPDFExport, lr_e_fclpdf;

type

  TGenType = (gtPreview, gtPDF, gtPrint);

  { TForm1 }

  TForm1 = class(TForm)
    Button1: TButton;
    Button2: TButton;
    cbprinter: TComboBox;
    CheckBox1: TCheckBox;
    CheckBox2: TCheckBox;
    conn: TSQLConnector;
    frDBDataSet1: TfrDBDataSet;
    frReport1: TfrReport;
    Label1: TLabel;
    lrcr: TlrCodeReport;
    lrPDFExport1: TlrPDFExport;
    query: TSQLQuery;
    tran: TSQLTransaction;
    rgtemplate: TRadioGroup;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    function PtToMm(i: Integer): Integer;
  public
    procedure GenerateReport(aType: TGenType; aPrinterIndex: Integer = 0);
    procedure TemplateA4x3L(Sender: TObject);
    procedure TemplateA4x3R(Sender: TObject);
    procedure TemplateA4x4(Sender: TObject);
    procedure TemplateA3x3(Sender: TObject);
  end;

var
  Form1: TForm1;

implementation

{$R *.lfm}

{ TForm1 }

procedure TForm1.Button1Click(Sender: TObject);
begin
  if CheckBox2.Checked then
    GenerateReport(gtPDF)
  else
    GenerateReport(gtPreview);
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  GenerateReport(gtPrint, cbprinter.ItemIndex);
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  cbprinter.Items.Assign(Printer.Printers);
  if cbprinter.Items.Count > 0 then
    cbprinter.ItemIndex := 0;
end;

function TForm1.PtToMm(i: Integer): Integer;
begin
  Result := trunc(i * 91 / 25.4);
end;

procedure TForm1.GenerateReport(aType: TGenType; aPrinterIndex: Integer);
begin
  if rgtemplate.ItemIndex < 0 then
  begin
    ShowMessage('Select report');
    exit;
  end;
  //connect to db
  conn.DatabaseName := 'etikett.db';
  conn.ConnectorType := 'SQLite3';
  conn.Connected := True;
  tran.Active := True;
  //open query
  query.SQL.Text := ' select * from tpostwurf ';
  query.Open;
  lrcr.Report.Clear;
  if CheckBox1.Checked then
    lrcr.Report.LoadFromFile('report.lrf');
  case rgtemplate.ItemIndex of
    0: lrcr.OnBeginReport := @TemplateA4x3L;
    1: lrcr.OnBeginReport := @TemplateA4x3R;
    2: lrcr.OnBeginReport := @TemplateA4x4;
    3: lrcr.OnBeginReport := @TemplateA3x3;
  end;
  lrcr.RunReport(aType = gtPreview);
  if aType <> gtPreview then

  begin
    lrcr.Report.PrepareReport;
    if aType = gtPDF then
    begin
      lrcr.Report.ExportTo(TlrPdfExportFilter, 'report.pdf');
      OpenDocument('report.pdf');
    end
    else
    begin
      lrcr.Report.ChangePrinter(0, aPrinterIndex);
      lrcr.Report.PrintPreparedReport('', 1);
    end;
  end;
  query.Close;
  tran.Active := False;
  conn.Connected := False;
end;

procedure TForm1.TemplateA4x3L(Sender: TObject);
var
  TextStyle: TlrTextRectStyle;
  i: Integer;
  h: double;
begin
  with Sender as TlrCodeReport do
  begin
    //set dimensions in mm
    SetRatio(trunc(91 / 25.4), trunc(91 / 25.4));
    //font style
    TextStyle := GetDefaultTextRectStyle;
    TextStyle.FontName := 'Arial';
    TextStyle.FontSize := 14;
    TextStyle.WordWrap := True;
    TextStyle.WordBreak := True;
    TextStyle.FontColor := clBlack;
    //line style
    TextStyle.Line.LWidth := 0.1;
    //start
    query.First;
    i := 0;
    while not query.EOF do
    begin
      Inc(i);
      if i = 1 then
      begin
        //add page
        NewPage;
        //set page format
        SetPaper(9 {A4}, poPortrait);
        //section height
        h := GetPageHeight / 3;
      end;
      //print address
      DrawText(30, i * h - 30 - 15, 85, 30, query.FieldByName('etikett3').Text, TextStyle);
      //draw line
      DrawLine(0, i * h, GetPageWidth, 0, TextStyle.Line);
      if i = 3 then
        i := 0;
      query.Next;
    end;
  end;
end;

procedure TForm1.TemplateA4x3R(Sender: TObject);
var
  TextStyle: TlrTextRectStyle;
  i: Integer;
  h: double;
begin
  with Sender as TlrCodeReport do
  begin
    //set dimensions in mm
    SetRatio(trunc(91 / 25.4), trunc(91 / 25.4));
    //font style
    TextStyle := GetDefaultTextRectStyle;
    TextStyle.FontName := 'Arial';
    TextStyle.FontSize := 12;
    TextStyle.WordWrap := True;
    TextStyle.WordBreak := True;
    TextStyle.FontColor := clBlack;
    //start
    query.First;
    i := 0;
    while not query.EOF do
    begin
      Inc(i);
      if i = 1 then
      begin
        //add page
        NewPage;
        //set page format
        SetPaper(9 {A4}, poPortrait);
        //draw dimension grid
        TextStyle.FontColor := clSilver;
        TextStyle.FontSize := 6;
        TextStyle.FontStyle := [fsItalic];
        TextStyle.Line.LWidth := 1;
        TextStyle.Line.LColor := clSilver;
        h := 0;
        while h < GetPageHeight do
        begin
          h := h + 5;
          if trunc(h) mod 10 = 0 then
            TextStyle.Line.LStyle := frsDash
          else
            TextStyle.Line.LStyle := frsDot;
          DrawLine(0, h, GetPageWidth, 0, TextStyle.Line);
          if trunc(h) mod 10 = 0 then
            DrawText(3, h - 3, 10, 10, FormatFloat('0" mm"', h), TextStyle);
        end;
        TextStyle.Line.LColor := clBlack;
        TextStyle.Line.LStyle := frsSolid;
        TextStyle.Line.LWidth := 0.1;
        TextStyle.FontSize := 12;
        TextStyle.FontColor := clBlack;
        TextStyle.FontStyle := [];
        //section height
        h := GetPageHeight / 3;
      end;
      //print address
      DrawText(110, i * h - 30 - 15, 85, 30, query.FieldByName('etikett3').Text, TextStyle);
      //draw line
      DrawLine(0, i * h, GetPageWidth, 0, TextStyle.Line);
      if i = 3 then
        i := 0;
      query.Next;
    end;
  end;
end;

procedure TForm1.TemplateA4x4(Sender: TObject);
var
  TextStyle: TlrTextRectStyle;
  i: Integer;
  h: double;
begin
  with Sender as TlrCodeReport do
  begin
    //set dimensions in mm
    SetRatio(trunc(91 / 25.4), trunc(91 / 25.4));
    //font style
    TextStyle := GetDefaultTextRectStyle;
    TextStyle.FontName := 'Arial';
    TextStyle.FontSize := 10;
    TextStyle.WordWrap := True;
    TextStyle.WordBreak := True;
    TextStyle.FontColor := clBlack;
    //line style
    TextStyle.Line.LWidth := 0.1;
    //start
    query.First;
    i := 0;
    while not query.EOF do
    begin
      Inc(i);
      if i = 1 then
      begin
        //add page
        NewPage;
        //set page format
        SetPaper(9 {A4}, poPortrait);
        //section height
        h := GetPageHeight / 4;
      end;
      //print address
      DrawText(30, i * h - 20 - 15, 85, 20, query.FieldByName('etikett3').Text, TextStyle);
      //draw line
      DrawLine(0, i * h, GetPageWidth, 0, TextStyle.Line);
      if i = 4 then
        i := 0;
      query.Next;
    end;
  end;
end;

procedure TForm1.TemplateA3x3(Sender: TObject);
var
  TextStyle: TlrTextRectStyle;
  i: Integer;
  h: double;
begin
  with Sender as TlrCodeReport do
  begin
    //set dimensions in mm
    SetRatio(trunc(91 / 25.4), trunc(91 / 25.4));
    //font style
    TextStyle := GetDefaultTextRectStyle;
    TextStyle.FontName := 'Arial';
    TextStyle.FontSize := 18;
    TextStyle.WordWrap := True;
    TextStyle.WordBreak := True;
    TextStyle.FontColor := clBlack;
    //line style
    TextStyle.Line.LWidth := 2;
    TextStyle.Line.LStyle := frsDash;
    //start
    query.First;
    i := 0;
    while not query.EOF do
    begin
      Inc(i);
      if i = 1 then
      begin
        //add page
        NewPage;
        //set page format
        SetPaper(8 {A3}, poPortrait);
        //section height
        h := GetPageHeight / 3;
      end;
      //print address
      DrawText(30, i * h - 50 - 15, 100, 50, query.FieldByName('etikett3').Text, TextStyle);
      //draw line
      DrawLine(0, i * h, GetPageWidth, 0, TextStyle.Line);
      if i = 3 then
        i := 0;
      query.Next;
    end;
  end;
end;

end.

